@@ -152,7 +152,9 @@ EXTENSIONS = {
     'ss': {'text', 'scheme'},
     'styl': {'text', 'stylus'},
     'sql': {'text', 'sql'},
+    'sv': {'text', 'system-verilog'},
     'svg': {'text', 'image', 'svg'},
+    'svh': {'text', 'system-verilog'},
     'swf': {'binary', 'swf'},
     'swift': {'text', 'swift'},
     'swiftdeps': {'text', 'swiftdeps'},
@@ -168,7 +170,10 @@ EXTENSIONS = {
     'tsx': {'text', 'tsx'},
     'ttf': {'binary', 'ttf'},
     'txt': {'text', 'plain-text'},
+    'v': {'text', 'verilog'},
     'vdx': {'text', 'vdx'},
+    'vh': {'text', 'verilog'},
+    'vhd': {'text', 'vhdl'},
     'vim': {'text', 'vim'},
     'vue': {'text', 'vue'},
     'war': {'binary', 'zip', 'jar'},
